EndpointJS class

Available extensions
Annotations

Constructors

EndpointJS()

Properties

adSrc → String?

Available on EndpointJS, provided by the EndpointJSExtension extension

no setter
cdn → String?

Available on EndpointJS, provided by the EndpointJSExtension extension

no setter
contentProtection → DistributionContentProtectionConfigurationJS?

Available on EndpointJS, provided by the EndpointJSExtension extension

no setter
daiAssetKey → String?

Available on EndpointJS, provided by the EndpointJSExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hespSrc → String?

Available on EndpointJS, provided by the EndpointJSExtension extension

no setter
hlsSrc → String?

Available on EndpointJS, provided by the EndpointJSExtension extension

no setter
priority → int

Available on EndpointJS, provided by the EndpointJSExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight → int

Available on EndpointJS, provided by the EndpointJSExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited