HespLatenciesJS class

Available extensions
Annotations

Constructors

HespLatenciesJS()

Properties

distributionLatency JSNumber?

Available on HespLatenciesJS, provided by the HespLatenciesJSExtension extension

no setter
engineLatency JSNumber?

Available on HespLatenciesJS, provided by the HespLatenciesJSExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
playerLatency JSNumber?

Available on HespLatenciesJS, provided by the HespLatenciesJSExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theoliveLatency JSNumber?

Available on HespLatenciesJS, provided by the HespLatenciesJSExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited