IntentToFallbackReasonJS class

Available extensions
Annotations

Constructors

IntentToFallbackReasonJS()

Properties

code → String?

Available on IntentToFallbackReasonJS, provided by the IntentToFallbackReasonJSExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?

Available on IntentToFallbackReasonJS, provided by the IntentToFallbackReasonJSExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited