THEOplayerArrayList<T> class

Implemented types
Available extensions
Annotations

Constructors

THEOplayerArrayList()

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int

Available on THEOplayerArrayList<T>, provided by the THEOplayerArrayListExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListener(String eventType, JSFunction<Function> fn) → void

Available on THEOplayerEventListener, provided by the THEOplayerEventListenerExtension extension

getItem(int index) → T

Available on THEOplayerArrayList<T>, provided by the THEOplayerArrayListHelpers extension

Get an item safely from THEOplayerArrayList
getLength() → int

Available on THEOplayerArrayList<T>, provided by the THEOplayerArrayListHelpers extension

Get the length safely from THEOplayerArrayList
item(int index) → JSAny?

Available on THEOplayerArrayList<T>, provided by the THEOplayerArrayListExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String eventType, JSFunction<Function> fn) → void

Available on THEOplayerEventListener, provided by the THEOplayerEventListenerExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited