THEOplayerTheoLiveApi class

Implemented types
Available extensions
Annotations

Constructors

THEOplayerTheoLiveApi()

Properties

badNetworkMode bool

Available on THEOplayerTheoLiveApi, provided by the THEOplayerTheoLiveApiExtension extension

getter/setter pair
currentLatency JSNumber?

Available on THEOplayerTheoLiveApi, provided by the THEOplayerTheoLiveApiExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
latencies HespLatenciesJS?

Available on THEOplayerTheoLiveApi, provided by the THEOplayerTheoLiveApiExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListener(String eventType, JSFunction fn) → void

Available on THEOplayerEventListener, provided by the THEOplayerEventListenerExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preloadPublications(JSArray<JSAny?> publicationIds) JSAny?

Available on THEOplayerTheoLiveApi, provided by the THEOplayerTheoLiveApiExtension extension

removeEventListener(String eventType, JSFunction fn) → void

Available on THEOplayerEventListener, provided by the THEOplayerEventListenerExtension extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited