TimeUpdateEventJS class

Available extensions
Annotations

Constructors

TimeUpdateEventJS()

Properties

currentProgramDateTime ↔ JSDate?

Available on TimeUpdateEventJS, provided by the TimeUpdateEventJSExtension extension

getter/setter pair
currentTime ↔ double

Available on TimeUpdateEventJS, provided by the TimeUpdateEventJSExtension extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited