TypedSource class

Available extensions
Annotations

Constructors

TypedSource({required String src, String? type, ContentProtection? contentProtection, String? integration, bool? hlsDateRange})
factory

Properties

contentProtection → ContentProtection?

Available on TypedSource, provided by the TypedSourceExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hlsDateRange → bool?

Available on TypedSource, provided by the TypedSourceExtension extension

no setter
integration → String?

Available on TypedSource, provided by the TypedSourceExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → String

Available on TypedSource, provided by the TypedSourceExtension extension

no setter
type → String?

Available on TypedSource, provided by the TypedSourceExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited