TextTrackImplWeb class
- Inheritance
-
- Object
- Track
- TextTrack
- TextTrackImpl
- TextTrackImplWeb
Constructors
- TextTrackImplWeb(String? id, int uid, String? label, String? language, String? kind, String? inBandMetadataTrackDispatchType, TextTrackReadyState readyState, TextTrackType type, Cues cues, Cues activeCues, String? source, bool isForced, TextTrackMode mode, THEOplayerTextTrack _nativeTextTrack)
Properties
- activeCues → Cues
-
The list of active cues of the track.
no setterinherited
- addCueEventListener ↔ dynamic
-
latefinal
- changeEventListener ↔ dynamic
-
latefinal
- cueChangeEventListener ↔ dynamic
-
latefinal
- cues → Cues
-
The list of cues of the track.
no setterinherited
- enterCueEventListener ↔ dynamic
-
latefinal
- exitCueEventListener ↔ dynamic
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
The identifier of the media track.
no setterinherited
- inBandMetadataTrackDispatchType → String?
-
The in-band metadata track dispatch type of the text track.
no setterinherited
- isForced → bool
-
Indicates whether the track contains Forced Narrative cues. This may only be true for subtitle tracks where
no setterinherited
- kind → String?
-
The kind of the media track, represented by a value from the following list:
no setterinherited
- label → String?
-
The label of the media track.
no setterinherited
- language → String?
-
The language of the media track.
no setterinherited
- readyState → TextTrackReadyState
-
The ready state of the text track.
no setterinherited
- removeCueEventListener ↔ dynamic
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String?
-
The source of the text track.
no setterinherited
- type → TextTrackType
-
The content type of the text track.
no setterinherited
- uid → int
-
A unique identifier of the media track.
Remarks:
no setterinherited
- unlocalizedLabel → String?
-
The unlocalized label of the media track.
no setterinherited
Methods
-
addEventListener(
String eventType, EventListener< Event> listener) → void -
inherited
-
dispatchEvent(
Event event) → void -
inherited
-
dispose(
) → void -
override
-
getMode(
) → TextTrackMode -
The mode of the text track, represented by a value from the following list:
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeEventListener(
String eventType, EventListener< Event> listener) → void -
inherited
-
setMode(
TextTrackMode mode) → void -
Sets mode of the text track, represented by a value from the following list:
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited