THEOplayerTimeRanges class

Available extensions
Annotations

Constructors

THEOplayerTimeRanges()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
length int

Available on THEOplayerTimeRanges, provided by the THEOplayerTimeRangesExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

end(int index) JSAny?

Available on THEOplayerTimeRanges, provided by the THEOplayerTimeRangesExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(int index) JSAny?

Available on THEOplayerTimeRanges, provided by the THEOplayerTimeRangesExtension extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited